# THIS FILE IS GENERATED FROM macrosynergy SETUP.PY
short_version: str = '0.0.31'
version: str = '0.0.31'
full_version: str = '0.0.31'
git_revision: str = '0c23d04e37da1cfb688d94ae12454dc1468e3124'
release: bool = True
if not release:
    version = full_version
